@@ -126,9 +126,9 @@ def remove_tracked_files(new_files:list, repo):
 @click.command()
 @click.pass_context
 def ignore(ctx):
-    '''
-    Add files to gitignore
-    '''
+    """
+    Add files to .gitignore with an interactive menu
+    """
     # recover repository's object from context
     repo = ctx.obj['REPO']
 
